#
# spec file for package zsh
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?rhel_version} || 0%{?centos_version} || 0%{?fedora_version}
%if 0%{?rhel_version} >= 700 || 0%{?centos_version} >= 700
%global __requires_exclude ^/bin/zsh$
%endif
BuildRequires:  libtermcap-devel
BuildRequires:  texi2html
BuildRequires:  texinfo
%endif
Name:           zsh
Version:        5.9
Release:        11.1
Summary:        Shell with comprehensive completion
License:        MIT
Group:          System/Shells
URL:            https://www.zsh.org
Source0:        https://downloads.sourceforge.net/project/zsh/zsh/%{version}/zsh-%{version}.tar.xz
Source1:        https://downloads.sourceforge.net/project/zsh/zsh/%{version}/zsh-%{version}.tar.xz.asc
Source2:        %{name}.keyring
Source3:        zshrc
Source4:        zshenv
Source5:        zprofile
Patch1:         trim-unneeded-completions.patch
# PATCH-FIX-OPENSUSE zsh-osc-completion.patch -- Fix openSUSE versions in osc completion
Patch2:         zsh-osc-completion.patch
# PATCH-FIX-OPENSUSE: taken from https://www.zsh.org/mla/workers/2022/msg00956.html
Patch3:         egrep-deprecation.patch
Patch4:         pipe-less-and-signals-handling.patch
Patch5:         zsh-ab4d62eb975a4c4c51dd35822665050e2ddc6918.patch
Patch6:         zsh-4c89849c98172c951a9def3690e8647dae76308f.patch
Patch7:         zsh-ac1fd06d7ce073c86f00d50fd74464bcb5194e97.patch
BuildRequires:  autoconf
BuildRequires:  groff
BuildRequires:  libcap-devel
BuildRequires:  ncurses-devel
BuildRequires:  pcre-devel
%if 0%{?rhel_version} || 0%{?centos_version} || 0%{?fedora_version}
Source11:       zlogin.rhs
Source12:       zlogout.rhs
Source13:       zprofile.rhs
Source14:       zshrc.rhs
Source15:       zshenv.rhs
Source16:       dotzshrc.rh
%endif
%if 0%{?suse_version}
BuildRequires:  fdupes
Requires(pre):  %{install_info_prereq}
%if 0%{?suse_version} >= 1210
BuildRequires:  makeinfo
BuildRequires:  texi2html
%endif
%else
Requires(pre):  /sbin/install-info
Requires(pre):  fileutils
Requires(pre):  grep
%endif
%if 0%{?suse_version} >= 1550
Provides:       /bin/zsh
%endif

%description
Zsh is a UNIX command interpreter (shell) that resembles the Korn shell
(ksh). It is not completely compatible. It includes many enhancements,
notably in the command-line editor, options for customizing its
behavior, file name globbing, features to make C-shell (csh) users feel
at home, and extra features drawn from tcsh (another `custom' shell).
Zsh is well known for its command line completion.

%package htmldoc
Summary:        Zsh shell manual in HTML format
Group:          Documentation/HTML
Provides:       %{name}-html = %{version}
Obsoletes:      %{name}-html < %{version}

%description htmldoc
The zsh shell is a command interpreter usable as an interactive login
shell and as a shell script command processor.  Zsh resembles the ksh
shell (the Korn shell), but includes many enhancements.  Zsh supports
command line editing, built-in spelling correction, programmable
command completion, shell functions (with autoloading), a history
mechanism, and more.

This package contains the Zsh manual in HTML format.

%if 0%{?suse_version} >= 1550
%package sh
Summary:        Handle behaviour of /bin/sh
Group:          System/Shells
Requires:       zsh = %{version}
Conflicts:      alternative(sh)
Provides:       alternative(sh)
BuildArch:      noarch

%description sh
Use zsh as /bin/sh implementation.
%endif

%prep
%setup -q
%if 0%{?suse_version}
%patch -P 1 -p1
%endif
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1
%patch -P 6 -p1
%patch -P 7 -p1

# Remove executable bit
chmod 0644 Etc/changelog2html.pl

# Fix bindir path in some files
perl -p -i -e 's|%{_prefix}/local/bin|%{_bindir}|' \
    Doc/intro.ms Misc/globtests.ksh Misc/globtests \
    Misc/lete2ctl Util/check_exports Util/helpfiles \
    Util/reporter Functions/VCS_Info/test-repo-git-rebase-*

%build
TEXI2HTML=texi2html
export TEXI2HTML
%configure \
%if 0%{?suse_version}
    --with-term-lib="ncursesw" \
    --enable-cflags="%{optflags} -fPIE %(ncursesw6-config --cflags)" \
    --enable-ldflags="%(ncursesw6-config --libs) -pie -Wl,-z,relro" \
%endif
    --enable-fndir=%{_datadir}/%{name}/${version}/functions \
    --enable-site-fndir=%{_datadir}/%{name}/site-functions \
    --enable-function-subdirs \
    --enable-maildir-support \
    --with-tcsetpgrp \
    --enable-cap \
    --enable-multibyte \
    --enable-pcre \
    --enable-unicode9

# Copy _rpm completion from Redhat (bnc#900424)
%if 0%{?suse_version}
cp Completion/Redhat/Command/_rpm Completion/openSUSE/Command/_rpm
%endif

make %{?_smp_mflags} all info html

# generate intro.ps
groff -Tps -ms Doc/intro.ms > intro.ps

# better name for html documentation
install -d -m 0755 Doc/htmldoc/
mv Doc/*.html Doc/htmldoc

# remove some unwanted files in Etc/
rm -f Etc/Makefile* Etc/*.yo

%install
%if 0%{?rhel_version} || 0%{?centos_version} || 0%{?fedora_version}
%endif

%if 0%{?suse_version}
%make_install install.info
%else
  make DESTDIR=%{buildroot} install install.info
%endif

install -m 0755 -Dd  %{buildroot}/{etc,bin}

%if 0%{?suse_version}
# install SUSE configuration
install -m 0644 %{SOURCE3} %{SOURCE4} %{SOURCE5} %{buildroot}%{_sysconfdir}

# Create custom completion directory
mkdir %{buildroot}%{_sysconfdir}/zsh_completion.d
%endif

%if 0%{?rhel_version} || 0%{?centos_version} || 0%{?fedora_version}
# install RHEL || CentOS || Fedora configuration
for i in zlogin zlogout zprofile zshrc zshenv; do
  install -m 0644 $RPM_SOURCE_DIR/${i}.rhs %{buildroot}%{_sysconfdir}/$i
done
install -D -m 0644 %{SOURCE16} %{buildroot}%{_sysconfdir}/skel/.zshrc
%endif

%if 0%{?suse_version} < 1550
# link zsh binary
%if 0%{?suse_version} || 0%{?rhel} <= 6
ln -sf %{_bindir}/zsh %{buildroot}/bin/zsh
%endif
%endif

# Remove versioned zsh binary
rm -f %{buildroot}%{_bindir}/zsh-*
%if 0%{?rhel_version} || 0%{?centos_version} || 0%{?fedora_version}
rm -f %{buildroot}/%{_infodir}/dir
%endif

%if 0%{?suse_version} >= 1110
%fdupes %{buildroot}
%endif

#
# Create the symlink required for zsh-sh to handle /bin/sh
#
%if 0%{?suse_version} >= 1550
  ln -s %{_bindir}/zsh %{buildroot}%{_bindir}/sh
%endif

%check
%if 0%{?suse_version}
make %{?_smp_mflags} check
%else
# FixMe: sometimes failing Test
#+ fn:echo:2: write error: broken pipe
#+ fn:2: write error: inappropriate ioctl for device
mv Test/E01options.ztst Test/E01options.ztst.mvd
%ifarch s390 s390x ppc ppc64
  ( cd Test
    mkdir skipped
    mv Y*.ztst skipped )
%endif
  ZTST_verbose=0 make test
%endif

%preun
%if ! 0%{?suse_version}
  if [ "$1" = 0 ] ; then
    /sbin/install-info --delete %{_infodir}/zsh.info.gz %{_infodir}/dir \
      --entry="* zsh: (zsh).                  An enhanced bourne shell."
  fi
%endif

%post
%if ! 0%{?suse_version}
  if [ ! -f %{_sysconfdir}/shells ]; then
    echo "%{_bindir}/zsh" > %{_sysconfdir}/shells
  else
    grep -q "^%{_bindir}/zsh$" %{_sysconfdir}/shells \
      || echo "%{_bindir}/zsh" >> %{_sysconfdir}/shells
  fi

  /sbin/install-info %{_infodir}/zsh.info.gz %{_infodir}/dir \
    --entry="* zsh: (zsh).                  An enhanced bourne shell."
%endif

%postun
%if ! 0%{?suse_version}
  if [ "$1" = 0 ] ; then
    if [ -f %{_sysconfdir}/shells ] ; then
      TmpFile=`%{_bindir}/mktemp /tmp/.zshrpmXXXXXX`
      grep -v '^%{_bindir}/zsh$' %{_sysconfdir}/shells > $TmpFile
      cp -f $TmpFile %{_sysconfdir}/shells
      rm -f $TmpFile
      chmod 644 %{_sysconfdir}/shells
    fi
  fi
%endif

%files
%doc ChangeLog FEATURES LICENCE MACHINES META-FAQ NEWS README
%doc Etc/* intro.ps Misc/compctl-examples
%config(noreplace) %{_sysconfdir}/zshrc
%config(noreplace) %{_sysconfdir}/zshenv
%config(noreplace) %{_sysconfdir}/zprofile
%if 0%{?rhel_version} || 0%{?centos_version} || 0%{?fedora_version}
%config(noreplace) %{_sysconfdir}/zlogin
%config(noreplace) %{_sysconfdir}/zlogout
%config(noreplace) %{_sysconfdir}/skel/.zshrc
%endif

%if 0%{?suse_version}
%dir %{_sysconfdir}/zsh_completion.d
%endif

%{_bindir}/zsh
%if 0%{?suse_version} < 1550
%if 0%{?suse_version} || 0%{?rhel} <= 6
/bin/zsh
%endif
%endif
%{_libdir}/zsh/
%{_datadir}/zsh/
%{_infodir}/zsh.info*%{ext_info}
%{_mandir}/man1/zsh*.1%{ext_man}

%files htmldoc
%doc Doc/htmldoc/*

%if 0%{?suse_version} >= 1550
%files sh
%{_bindir}/sh
%endif

%changelog
* Mon Mar  3 2025 Paolo Perego <paolo.perego@suse.com>
- Fix bsc#1226450. Placing skip_global_compinit=1 in your $ZDOTDIR/.zshenv
  disables compinit from being called
* Mon Mar  3 2025 Paolo Perego <paolo.perego@suse.com>
- Applied solution for boo#1227119. In case you configured hostnames in
  ~/.ssh/config file, now TAB completion is working as expected.
* Mon Mar  3 2025 Paolo Perego <paolo.perego@suse.com>
- Adding zsh-ac1fd06d7ce073c86f00d50fd74464bcb5194e97.patch to fix a
  segmentation fault.
  53146: flags cannot be copied from an undefined function
* Mon Feb 17 2025 Dr. Werner Fink <werner@suse.de>
- Make it build with texinfo 7.1 (boo#1237196)
* Mon Jul 15 2024 Martin Jambor <mjambor@suse.com>
- Backport zsh-ab4d62eb975a4c4c51dd35822665050e2ddc6918.patch
  and zsh-4c89849c98172c951a9def3690e8647dae76308f.patch and add
  autoconf to build requirements to make the package build with
  GCC 14. [boo#1225958]
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Nov 30 2023 Paolo Perego <paolo.perego@suse.com>
- add pipe-less-and-signals-handling.patch (bsc#1217304). It fixes a problem
  with signal handling and less when the job is suspended in a user defined
  concatenated commands function.
* Thu Aug  3 2023 Andreas Schwab <schwab@suse.de>
- Enable testsuite in qemu build
* Tue Feb 28 2023 Paolo Perego <paolo.perego@suse.com>
- Disabled zsh-sh subpackage generation for Leap 15.4 to prevent an error when
  building the package.
* Tue Feb 28 2023 pgajdos@suse.com
- don't require yodl for build, doc is not regenerated anyway
* Tue Dec 27 2022 Ludwig Nussel <lnussel@suse.com>
- Replace transitional %%usrmerged macro with regular version check (boo#1206798)
* Sat Oct 22 2022 Luciano Santos <luc14n0@opensuse.org>
- Add zsh-sh subpackage to offer Zsh users a "native" way to handle
  /bin/sh scripts and use an SH shell with the capabilities of Zsh
  itself to emulate a Bourne shell. An 'sh' symlink pointing to the
  Zsh binary is all that is needed for it to emulate the Bourne
  shell, it is similar to the use of `emulate sh` Zsh's built-in
  command or the `zsh --emulate sh` shell command.
- Drop deprecated use of install_info(_delete) post(un) macros. RPM
  file triggers have replaced their functionality since 2019.
* Mon Sep 12 2022 Dirk Müller <dmueller@suse.com>
- add egrep-deprecation.patch (bsc#1203241)
* Sun May 15 2022 Dirk Müller <dmueller@suse.com>
- update to 5.9:
  zsh 5.9 is dedicated to the memory of Sven Guckes, who was, amongst other
  things, a long-time zsh advocate.  For more information, see:
    https://linuxnews.de/2022/02/sven-guckes-verstorben/
    https://groups.google.com/g/vim_announce/c/MJBKVd-xrEE/m/joVNaDgAAgAJ
  When unsetting a hash element, the string enclosed in square brackets is
  interpreted literally after any normal command-line-argument expansions.
  Thus
    unset "hash[$key]"
  first expands $key as usual for a double-quoted string, and then interprets
  that result as the exact hash element to unset.  This differs from previous
  versions of the shell, which would also remove a leading backslash for an
  unusual subset of characters in the expansion of $key.  Note this also
  means, for example, that now
    unset 'hash[ab]cd]'
  unsets the element with key "ab]cd" rather than silently doing nothing.
  The function command learnt a -T option to declare a function and enable
  tracing for it simultaneously.
  The option SHORT_REPEAT was added to enable the short syntax of
  SHORT_LOOPS for the repeat command only. It is disabled by default.
  The _arguments function now supports NUL-delimiting optargs in the
  opt_args array via the -0 option. Developers of completion functions
  should find this easier to handle reliably than the default
  colon-delimiting behaviour.
  The zsh/system module's `zsystem flock` command learnt an -i option to
  set the wait interval used with -t. Additionally, -t now supports
  fractional seconds.
  The option CLOBBER_EMPTY was added to enable the overwrite behaviour
  of CLOBBER for empty files only. It is disabled by default.
  A (-) expansion flag was added. It works like (n) but correctly sorts
  negative numbers.
  The (*) expansion flag enables EXTENDED_GLOB for pattern matching.
  For example, ${(*)sample/(#b)*(pat)*/${match[1]}} uses backreferences
  even if EXTENDED_GLOB is not otherwise set.  However, this does not
  descend into nested exapansions, and doubling as (**) does not disable
  EXTENDED_GLOB.
  The compinit function learnt a -w option to explain why compdump runs.
  When run without the -i or -u options and compaudit discovers security
  issues, answering "y" to the "Ignore insecure ..." prompt removes the
  insecure elements (like the -i option) where previously it ignored the
  result (thus formerly like the -u option).  Further, removing those
  elements includes dropping directories from the $fpath array.
  The zsh/datetime module's strftime builtin learnt an -n option to omit
  the trailing newline when printing a formatted time.
  The XTRACE option is now disabled while running user-defined completion
  widgets.  This corresponds to long-standing behavior of other user ZLE
  widgets.  Use the _complete_debug widget to capture XTRACE output, or
  use "functions -T" to enable tracing of specific completion functions.
  The fc builtin learnt an -s option which is a POSIX equivalent to the
  `fc -e-` method of re-executing a command without invoking an editor.
  The option CASE_PATHS was added to control how NO_CASE_GLOB behaves.
  NO_CASE_GLOB + NO_CASE_PATHS is equivalent to the current NO_CASE_GLOB
  behaviour. NO_CASE_GLOB + CASE_PATHS treats only path components that
  contain globbing characters as case-insensitive; this behaviour may
  yield more predictable results on case-sensitive file systems.
  NO_CASE_PATHS is the default.
  With the new TYPESET_TO_UNSET option set, "typeset foo" leaves foo unset,
  in contrast to the default behavior which assigns foo="".  Any parameter
  attributes such as numeric type, sorting, and padding are retained until
  the parameter is explicitly unset or a conflicting value is assigned.
  This is similar to default behavior of bash and ksh.  This option is
  disabled by default.
  The compadd builtin's -D option can now be specified more than once.
  The zsh/zutil module's zformat builtin learnt an -F option which behaves
  like -f except that ternary expressions check for existence instead of
  doing math evaluation.
  The conventional syntax used to indicate units, ranges, and default values
  in completion descriptions (e.g. `timeout (seconds) (0-60) [20]`) is now
  recognised by the completion system itself. These components are parsed
  out of the description and can be individually styled. A _numbers helper
  function has been added to help function authors offer rich completion
  for these values.
  The log builtin, WATCH parameter, et al., have been broken out into a
  separate module, zsh/watch. The module is enabled by default.
  The zsh/watch module's WATCHFMT parameter now supports colours via the
  %%F and %%K escapes.
  The STTY parameter can now be set to an empty string before running a
  command to automatically restore terminal settings after the command
  finishes.
  The "jobs" command and "$jobstates" and related parameters can report on
  parent shell jobs even in subshells.  This is a snapshot of the parent
  state, frozen at the point the subshell started.  However, if a subshell
  starts its own background jobs, the parent state is discarded in order
  to report on those new jobs.
- drop ncurses-fix.patch: upstream
* Sun Mar 20 2022 Dirk Müller <dmueller@suse.com>
- update to 5.8.1 (bsc#1196435, CVE-2021-45444):
  * CVE-2021-45444: Some prompt expansion sequences, such as %%F, support
    'arguments' which are themselves expanded in case they contain colour
    values, etc. This additional expansion would trigger PROMPT_SUBST
    evaluation, if enabled. This could be abused to execute code the user
    didn't expect. e.g., given a certain prompt configuration, an attacker
    could trick a user into executing arbitrary code by having them check
    out a Git branch with a specially crafted name.
    This is fixed in the shell itself by no longer performing PROMPT_SUBST
    evaluation on these prompt-expansion arguments.
    Users who are concerned about an exploit but unable to update their
    binaries may apply the partial work-around described in the file
    Etc/CVE-2021-45444-VCS_Info-workaround.patch included with the shell
    source. [ Reported by RyotaK <security@ryotak.me>. Additional thanks to
    Marc Cornellà <hello@mcornella.com>. ]
* Fri Oct 16 2020 Ludwig Nussel <lnussel@suse.de>
- prepare usrmerge (boo#1029961)
* Tue Aug 25 2020 Martin Liška <mliska@suse.cz>
- Add ncurses-fix.patch in order to fix ncurses failure.
* Tue May  5 2020 Mykola Krachkovsky <w01dnick@gmail.com>
- Add $HOME aliases to fix regression after dropping /etc/bash.bashrc
* Tue May  5 2020 Ismail Dönmez <idonmez@suse.com>
- Add back LS_COLORS, LS_OPTIONS and GPG_TTY
* Wed Apr 15 2020 Ismail Dönmez <idonmez@suse.com>
- Add aliases from /etc/bash.bashrc into /etc/zshrc so we don't
  regress
* Wed Apr  8 2020 Ismail Dönmez <idonmez@suse.com>
- Stop sourcing /etc/bash.bashrc which causes problems with ls, add
  a call to manually source /etc/zsh.zshrc.local if available.
* Tue Mar 10 2020 Martin Liška <mliska@suse.cz>
- Remove stack-protector option addition, it's already in $optflags.
* Mon Feb 17 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 5.8
  * Fixes CVE-2019-20044 bsc#1163882
* Fri Feb  7 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 5.8~pre3 (5.7.1-test-3)
  * Minor bugfixes compared to pre2
* Sun Dec 22 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 5.8~pre2 (5.7.1-test-2)
- Drop 1baf0d1f553631ecb641e98f4bf48bc2a44e5b82.patch, fixed
  upstream.
* Mon Dec 16 2019 Ismail Dönmez <idonmez@suse.com>
- Add 1baf0d1f553631ecb641e98f4bf48bc2a44e5b82.patch to fix a
  re-entrancy problem.
* Mon Dec 16 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 5.8~pre1 (5.7.1-test-1)
  * The zsh/zutil module's zparseopts builtin learnt an -F option to abort
    parsing when an unrecognised option-like parameter is encountered.
  * The zsh/files module gained a chmod builtin.
  * Several changes have been made to the way completion functions track
    'precommands' (such as `command` and `env`) and determine whether the
    command being completed for is a shell builtin. Developers of completion
    functions may wish to familiarise themselves with `_normal -p` and
    `_pick_variant -b`.
  * The option CD_SILENT was added to suppress all output from cd (whether
    explicit or implicit with AUTO_CD). It is disabled by default.
  * The compadd builtin's -o option now takes an optional argument to
    specify the order of completion matches. This affects the display
    of candidate matches and the order in which they are selected when
    cycling between them using menu completion.
  * The :h and :t modifiers in parameter expansion (if braces are present),
    glob qualifiers and history expansion may take following decimal digit
    arguments in order to keep that many leading or trailing path components
    instead of the defaults of all but one (:h) and one (:t).  In an absolute
    path the leading '/' counts as one component.
  * The functions builtin gained a -c option to efficiently copy functions.
- See included ChangeLog for the complete list of changes.
* Mon Feb  4 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 5.7.1
  * This release contains fixes for the two regressions reported
    with VCS_Info and prompt colour sequences.
* Fri Jan 25 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 5.7
  * Support for 24-bit true color terminals has been added.
    Hex triplets can be used when specifying colours for prompts
    and line editor highlighting. On 88 and 256 colour terminals,
    a new zsh/nearcolor module allows colours specified with hex
    triplets to be matched against the nearest available colour.
  * The zsh/datetime module's strftime builtin now accepts an
    argument specifying the nanoseconds time component; both
    arguments can be omitted to use the current time.
* Fri Sep 21 2018 Ismail Dönmez <idonmez@suse.com>
- Unbreak Leap 42.3 compilation
* Sun Sep 16 2018 Karol Babioch <kbabioch@suse.com>
- Update to version 5.6.2
  * Fix another SIGTTOU case.
  * Fix SIGWINCH being ignored when zsh is not in the foreground.
* Tue Sep 11 2018 Karol Babioch <kbabioch@suse.com>
- Update to version 5.6.1
  * Fix packaging issue that broke runhelp
  * Fix a regression with pipelines getting backgrounded and emitting SIGTTOU
* Tue Sep  4 2018 Ismail Dönmez <idonmez@suse.com>
- Update to version 5.6
  * Fixes CVE-2018-0502 (bsc#1107296) and
    CVE-2018-13259 (bsc#1107294)
  * Switch to -fstack-protector-strong
  * See included NEWS file for complete changes.
- No longer manually install help files, make install handles it.
- Workaround a regression upstream with help file generation by
  removing Doc/help.txt before build.
* Fri May 11 2018 kbabioch@suse.com
- Update to 5.5.1
  * fix for a configuration problem finding signal names from (some) recent
    versions of glibc
  * minor changes
* Thu Apr 12 2018 jengelh@inai.de
- Update RPM groups.
* Wed Apr 11 2018 kbabioch@suse.com
- Update to 5.5
  * The effect of the NO_INTERACTIVE_COMMENTS option extends into $(...)
    and `...` command substitutions when used on the command line.
  * Dropped patches, which are included upstream now:
  - zsh-CVE-2018-1071.patch
  - zsh-CVE-2018-1083.patch
  * Fixes a buffer overflow in utils.c:checkmailpath() that can lead to
    local arbitrary code execution (CVE-2018-1100 bnc#1089030)
* Tue Mar 27 2018 kbabioch@suse.com
- Added zsh-CVE-2018-1071.patch: Fixed a stack-based buffer overflow
  in exec.c:hashcmd() (CVE-2018-1071 bnc#1084656)
- Added zsh-CVE-2018-1083.patch: Fixed a stack-based buffer overflow
  in gen_matches_files() at compctl.c (CVE-2018-1083 bnc#1087026)
- Cleaned up spec file with spec-cleaner
* Tue Feb 27 2018 kbabioch@suse.com
- Updated to 5.4.2
  * The 'exec' and 'command' precommand modifiers, and options to
    them, are now parsed after parameter expansion.
  * Functions executed by ZLE widgets no longer have their standard
    input closed, but redirected from /dev/null instead.
  * There is an option WARN_NESTED_VAR, a companion to the existing
    WARN_CREATE_GLOBAL that causes a warning if a function updates a
    variable from an enclosing scope without using typeset -g.
  * zmodload now has an option -s to be silent on a failure to find
    a module but still print other errors.
- Dropped patch merged upstream:
  * fix-patchutils-completion.patch
* Sun Mar  5 2017 rpm@fthiessen.de
- Update to 5.3.1
  * Fix typo in chflags completion
  * Fixed invalid git commands completion
  * VCS info system: vcs_info git: Avoid a fork.
  * Fix handling of "printf -" and "printf --"
- Removed upstream merged fix-printf.patch
* Tue Jan 10 2017 jmatejek@suse.com
- fix broken completion for filterdiff: fix-patchutils-completion.patch
  (boo#1019130)
* Wed Dec 14 2016 idonmez@suse.com
- Update to zsh 5.3
  * Unicode9 support, this needs support from your terminal to
    work correctly.
  * The new word modifier ':P' computes the physical path of the
    argument.
  * The output of "typeset -p" uses "export" commands or the "-g"
    option for parameters that are not local to the current scope.
  * vi-repeat-change can repeat user-defined widgets if the widget
    calls zle -f vichange.
  * The parameter $registers now makes the contents of vi register
    buffers available to user-defined widgets.
  * New vi-up-case and vi-down-case builtin widgets bound to gU/gu
    (or U/u in visual mode) for doing case conversion.
  * A new select-word-match function provides vim-style text objects
    with configurable word boundaries using the existing
    match-words-by-style mechanism.
  * Support for the conditional expression [[ -v var ]] to test if a
    variable is set for compatibility with other shells.
  * The print and printf builtins have a new option -v to assign the
    output to a variable.
  * New x: syntax in completion match specifications make it possible
    to disable match specifications hardcoded in completion functions.
- Re-add custom zshrc and zshenv to unbreak compatibility with old
  usage (boo#998858).
- Add fix-printf.patch to fix a regression in printf.
* Thu Sep  8 2016 idonmez@suse.com
- Read /etc/profile as zsh again.
* Tue Aug 30 2016 mmanno@suse.com
- Remove custom zshrc and zshenv as they might interfere with the users config
- Remove unused zshprompt.pl
- Move install outside loop in spec file, was executed too often
* Wed May 25 2016 llua@gmx.com
- Add CentOS [67] support
* Thu Dec 10 2015 mpluskal@suse.com
- Add gpg signature
* Thu Dec  3 2015 idonmez@suse.com
- Update to version 5.2
  * The new module zsh/param/private can be loaded to allow the shell
    to define parameters that are private to a function scope (i.e. are
    not propagated to nested functions called within this function).
  * The GLOB_STAR_SHORT option allows the pattern **/* to be shortened to
    just ** if no / follows. so **.c searches recursively for a file whose
    name has the suffix ".c".
  * The effect of the WARN_CREATE_GLOBAL option has been significantly
    extended, so expect it to cause additional warning messages about
    parameters created globally within function scope.
* Thu Nov  5 2015 idonmez@suse.com
- Remove -Wl,-z,now it breaks module loading rh#1277996
* Sat Sep 12 2015 idonmez@suse.com
- Update to version 5.1.1
  * Bug fixes for regressions in 5.1 release
- Remove read1char_signals.patch, fixed upstream.
* Tue Sep  1 2015 idonmez@suse.com
- Add read1char_signals.patch to fix workers/36373
* Tue Sep  1 2015 idonmez@suse.com
- Update to version 5.1
  * The print builtin has new options -x and -X to expand tabs.
  * Several new command completions and numerous updates to others.
  * Options to "fc" to segregate internal and shared history.
  * All emulations including "sh" use multibyte by default; several
    repairs to multibyte handling.
  * ZLE supports "bracketed paste" mode to avoid interpreting pasted
    newlines as accept-line.  Pastes can be highlighted for visibility
    and to make it more obvious whether accept-line has occurred.
  * Improved (though still not perfect) POSIX compatibility for getopts
    builtin when POSIX_BUILTINS is set.
  * New setopt APPEND_CREATE for POSIX-compatible NO_CLOBBER behavior.
  * Completion of date values now displays in a calendar format when
    the complist module is available.  Controllable by zstyle.
  * New parameter UNDO_LIMIT_NO for more control over ZLE undo repeat.
  * Several repairs/improvements to the contributed narrow-to-region
    ZLE function.
  * Many changes to child-process and signal handling to eliminate race
    conditions and avoid deadlocks on descriptor and memory management.
  * New builtin sysopen in zsh/system module for detailed control of
    file descriptor modes.
- Remove printf-regress.patch, upstream.
* Sun Jun 14 2015 idonmez@suse.com
- Add printf-regress.patch to fix a printf regression boo#934175
* Sun May 31 2015 idonmez@suse.com
- Update to version 5.0.8
  * Global aliases can be created for syntactic tokens such as command
    separators (";", "&", "|", "&&", "||"), redirection operators, etc.
  * There have been various further improvements to builtin handling
    with the POSIX_BUILTINS option (off by default) for compatibility with
    the POSIX standard.
  * 'whence -v' is now more informative, and 'whence -S' shows you
    how a full chain of symbolic links resolves to a command.
  * The 'p' parameter flag now allows an argument to be specified
    as a reference to a variable, e.g. ${(ps.$sep.)foo} to split $foo
    on a string given by $sep.
  * The option FORCE_FLOAT now forces variables, not just constants,
    to floating point in arithmetic expressions.
  * The type of an assignment in arithmetic expressions, e.g. the
    type seen by the variable res in $(( res = a = b )), is now
    more logical and C-like.
  * The default binding of 'u' in vi command mode has changed to undo
    multiple changes when invoked repeatedly. '^R' is now bound to redo
    changes. To revert to toggling of the last edit use:
    bindkey -a u vi-undo-change
  * Compatibility with Vim has been improved for vi editing mode. Most
    notably, Vim style text objects are supported and the region can be
    manipulated with vi commands in the same manner as Vim's visual mode.
  * Elements of the watch variable may now be patterns.
  * The logic for retrying history locking has been improved.
- Remove gcc5-fix.patch, fixed upstream.
* Sun May  3 2015 dmitry_r@opensuse.org
- Fix openSUSE versions in osc completion
  * zsh-osc-completion.patch
* Wed Apr 29 2015 idonmez@suse.com
- Add gcc5-fix.patch to fix signames.c generation with gcc5
* Wed Apr 22 2015 hvogel@opensuse.org
- Nowadays more and more terminals set $TERM to xterm-256color
* Tue Feb 10 2015 dimstar@opensuse.org
- BuildRequire texi2html instead of texinfo: the packages have been
  split completely now.
* Wed Jan 28 2015 idonmez@suse.com
- Add back rpm completion file (bnc#900424)
* Wed Jan 14 2015 idonmez@suse.com
- Harden CFLAGS/LDFLAGS
* Thu Oct  9 2014 idonmez@suse.com
- Update to version 5.0.7
  * Small bugfixes
  * Includes a security fix to disallow evaluation of the
    initial values of integer variables imported from the environment
- Remove zsh-fix-pcre-n.patch, fixed upstream
* Sun Sep  7 2014 idonmez@suse.com
- Add zsh-fix-pcre-n.patch to fix pcre_match() -n option
* Thu Aug 28 2014 idonmez@suse.com
- Update to version 5.0.6
  * See included ChangeLog
- Remove zsh-update-zypper-completion.patch, fixed upstream
* Wed Aug  6 2014 idonmez@suse.com
- Rename Completion/openSUSE/Command/_SuSEconfig to _SUSEconfig
  (bnc#888989 fate#316521)
* Fri Jan 17 2014 idonmez@suse.com
- Update zsh-update-zypper-completion.patch to v0.3
* Thu Jan 16 2014 idonmez@suse.com
- Add zsh-update-zypper-completion.patch to update zypper
  completions, patch by Holger Macht and Thomas Mitterfellner.
* Tue Jan  7 2014 idonmez@suse.com
- Update to version 5.0.5
  * Fixes a couple of regression in 5.0.4
- Remove zsh-pipefix.patch, merged upstream
* Wed Dec 25 2013 idonmez@suse.com
- Update to version 5.0.4
  * Small bugfix release
- Add zsh-pipefix.patch to import pipe fixes from zsh.git
- Remove upstream patches
  * zsh-osc-suseversion.patch
  * zsh-zypper-completion.patch
* Mon Apr 22 2013 idonmez@suse.com
- Don't set globdots it might lead to unexpected problems (bnc#815556)
* Thu Mar 21 2013 idonmez@suse.com
- Fix custom completion support via /etc/zsh_completion.d (bnc#811356)
- Add trim-unneeded-completions.patch to remove unneeded completions
  when building for openSUSE
* Sun Jan 27 2013 dmitry_r@opensuse.org
- Fix zypper completion [bnc#752112]
  * zsh-zypper-completion.patch
- Fix osc completion (SUSE versions)
  * zsh-osc-suseversion.patch
* Mon Dec 24 2012 idonmez@suse.com
- Update to version 5.0.2
  * Numeric constants in mathematical contexts can contain
    underscores.
  * functions -T turns on tracing for specific functions.
- See the included NEWS file for other changes.
* Fri Nov 16 2012 crrodriguez@opensuse.org
- Test suite runs flaky in qemu-arm, disable it for now.
* Fri Oct 26 2012 coolo@suse.com
- buildrequire groff needed to build helpfiles
* Thu Aug  9 2012 idonmez@suse.com
- Version update to 5.0.0
  * No real changes since 4.3.17
* Sun Jul 22 2012 coolo@suse.com
- we need tex2html too, which is provided by texinfo
* Thu Jul 19 2012 coolo@suse.com
- buildrequire makeinfo to fix build
* Mon Feb 27 2012 idonmez@suse.com
- Update to version 4.3.17
  * Contains fixes for possible speed regression introduced
    in 4.3.15 (new option HASH_EXECUTABLES_ONLY)
  * Improvements to (bash) completion and shell emulation mode
- Drop all the patches, all upstream
* Tue Feb  7 2012 hmacht@suse.de
- add zsh-enable-openSUSE-completion-functions.patch: Enable
  installation of openSUSE completion functions which are upstream
* Tue Jan 31 2012 idonmez@suse.com
- Update _osc completion
* Sat Dec 31 2011 idonmez@suse.com
- Instead of disabling c02cond manually, add upstream patch to
  automatically disable it on noatime mounted systems.
* Tue Dec 20 2011 idonmez@suse.com
- Update to zsh 4.3.15
  * Fix POSIX compatibility
* Wed Dec  7 2011 idonmez@suse.com
- Update to zsh 4.3.14
  * Drop 74eed99c312de05e19b54ba6b5d37a0aeb4ba713.patch and
    724fd07a67f135c74eba57e9f25fd342201ec722.patch, fixed upstream
  * Fix for nanosecond timestamp support
* Mon Dec  5 2011 idoenmez@suse.de
- Fix license to be MIT, zsh seems to be using the "Modern" variant
  of the license text.
- Import git commits 74eed99c312de05e19b54ba6b5d37a0aeb4ba713 and
  724fd07a67f135c74eba57e9f25fd342201ec722
  * metafy() added null termination even if buffer was not modifiable
  * Fix uninitialised memory after lexer realloc
* Wed Nov 30 2011 idoenmez@suse.de
- Update to zsh 4.3.13
  * There are no significant feature changes to the shell itself,
    although many bug fixes and improvements to functions.
  * See included ChangeLog for details
- Drop zsh-4.3.12-ksh-emulation-syntax-checking.patch,
  fixed upstream
* Tue Nov 29 2011 idoenmez@suse.de
- Cleanup spec file
- Make /bin/zsh a symlink to /usr/bin/zsh
* Mon Nov 28 2011 idoenmez@suse.de
- Update to 4.3.12-test3
  * See included ChangeLog for details
- Drop zsh-findproc.patch and zsh-kill-suspended-job.patch, fixed
  upstream.
* Thu Nov 24 2011 idoenmez@suse.de
- Add custom completion support via /etc/zsh_completion.d
- Fix build with new ncurses library
* Mon Aug  1 2011 crrodriguez@opensuse.org
- Enable pcre module
- Build against ncurses6w instead of plain old ncurses5
* Wed Jun 29 2011 chris@computersalat.de
- enable build for RHEL and friends (CentOS, Fedora)
  o merge with 4.2.6 from RHEL
  o add/rework RHEL patch (BZ-488943-ksh-emulation-syntax-checking)
  o add several *.rhs files
  o disable E01options test
- add subpkg htmldoc
- fix deps
  o fdupes >= suse_version 1110
* Fri Jun 17 2011 idonmez@novell.com
- Add zsh-kill-suspended-job.patch: fix killing suspended jobs
- Add zsh-findproc.patch: fix findproc() to find stopped jobs
* Wed Jun  1 2011 idonmez@novell.com
- Update to zsh 4.3.12
- Dropped openSUSE specific completions, all are upstreamed now
* Tue Apr 26 2011 idoenmez@novell.com
- Enable make check
* Thu Apr 21 2011 idoenmez@novell.com
- Disable zsh debug
- Enable strict aliasing again
* Wed Apr 20 2011 idoenmez@novell.com
- Update to 4.3.11-dev-2, many crash fixes
* Tue Mar 15 2011 ismail@namtrac.org
- Fix crash with ${foo:0:}
* Wed Dec 29 2010 cristian.rodriguez@opensuse.org
- Update to version 4.3.11
  * The completion system now has a style path-completion.
  * new "zsystem" builtin whose subcommands perform system level tasks
  * Added "D" and "Z" flag in parameter expansion
  * Lots of other bugfixes/improvements, see Changelog
* Tue Mar  9 2010 hmacht@suse.de
- update completion for _osc:
  - add new products openSUSE 11.2 and openSUSE 11.3
  - add possibility to extend the list of projects and build
    targets with user defined variables
    $ZSH_OSC_BUILD_TARGETS_EXTRA and $ZSH_OSC_PROJECTS_EXTRA
* Wed Dec  2 2009 coolo@novell.com
- update patch to apply with fuzz=0
* Thu Oct  8 2009 coolo@novell.com
- disable profiling for now
* Thu Aug 20 2009 hvogel@novell.com
- Fix zshrc. Lost some features by not including bash.bashrc
* Wed Aug  5 2009 hvogel@suse.de
- update to version 4.3.10
  o The command "emulate <mode> -c ..." evaluates an expression in
    a given emulation.
  o The variable CORRECT_IGNORE gives a pattern that can be ignored
    in spelling correction.
  o The option POSIX_ALIASES improves compatibility of aliases with
    other shells.
  o The option COMBINING_CHARS has been added.  When it is set, the
    line editor assumes the terminal is capable of displaying
    zero-width combining characters (typically accents) correctly
    as modifications to the base character, and will act accordingly.
  o The option HIST_FCNTL_LOCK has been added to provide locking of
    history files
  o The syntax ~[...] provides a dynamic form of directory naming,
    supplementing the existing static ~name syntax.
  o Patterns can now be used in incremental searches with new widgets
  o Highlighting and colouring of sections of the command line is now
    supported
  o Colouring of prompts is now supported within the shell by prompt
    escapes.
  o Various changes have been added to make debugging of shell code
    easier
  o The "fc" builtin has been enhanced to make non-interactive use
    possible and output consistent when the history is manipulated
    with "print -s".
  o The completion style accept-exact-dirs has been added
  o cd, chdir, pushd and popd now take a -q option to suppress side effects
- cleanup patches
- use fdupes
- install help files to versioned directory
* Fri Apr 24 2009 hmacht@suse.de
- add completion for osc (_osc)
- add completion for zypper (_zypper)
* Thu Oct  2 2008 hvogel@suse.de
- globally disabling the test was the plan, not only on some archs
* Thu Sep 18 2008 hvogel@suse.de
- disable another test globally which keeps hanging
* Tue Jun 17 2008 hvogel@suse.de
- disable one test globally
* Thu Apr  3 2008 hvogel@suse.de
- update to 4.3.6
  * Various bugfixes
  * various buildfixes
  * for calendar_show use kdialog rather than xmessage if in KDE
  * clarify the message printed when compaudit finds problems
  * improve compsys option handling
  * add -q option to cd, chdir, pushd, popd
  * wait shouldn't return immediately on a signal unless it's
    trapped
  * fix not enough space for ztrftime string with multibyte
    characters
* Tue Mar 25 2008 hvogel@suse.de
- Disable some tests on  s390, s390x, ppc and ppc64
* Thu Mar 20 2008 hvogel@suse.de
- update to 4.3.5
  * Various bugfixes
  * stop tindent becoming negative, which causes infinite use of
  memory; add debug test to see where it would become negative.
  * make malloc(0) allocate a single byte instead of returning
  invalid (and unfreeable) memory.
  * fix race in POSIX signal blocking
  * various completion fixes/updates, mostly git
  * tidy up module interface and documentation
  * more build tests
  * The new extended globbing flag (#cN,M) behaves similarly to
  the extended regular expression syntax {N,M}.
  * The zsh/datetime module has been enhanced and a calendar function
  system has been added along the lines of (but much enhanced from)
  * A new module zsh/curses provides a builtin zcurses for access to
  to the curses screen manipulation package.
* Mon Dec  3 2007 hvogel@suse.de
- cleanup initialization files
  * Dont source profile from zshenv. profile is not for interactive
    shells [#343621]
  * Instead source profile from zprofile so we dont loose the features
    and its easy to get rid of it.
  * Source bash.bashrc from zshrc to keep the features and make it
    possible to get rid of it easier.
* Wed Jul  4 2007 hvogel@suse.de
- update to version 4.3.4
  * various bugfixes
  * countless completion fixes
  * some new completions
  * various UTF8 fixes
- remove autoresume option from default config [#287776]
* Fri Mar 30 2007 rguenther@suse.de
- add ncurses-devel BuildRequires.
* Fri Jul 14 2006 mskibbe@suse.de
- merged in patches from poeml (mruecker@suse.de)
- rediffed patches for -p0 (mruecker@suse.de)
- update to version 4.3.2 which (mruecker@suse.de)
  o fix two minor build problems
  o contains initial support for multibyte characters in the shell's line editor
- only require libcap for build on 10.0 and older (mruecker@suse.de)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 schwab@suse.de
- Don't strip binaries.
* Mon Dec  5 2005 hvogel@suse.de
- clean up specfile
- document profiling builds
* Mon Dec  5 2005 mmj@suse.de
- Fix typo
* Mon Dec  5 2005 mmj@suse.de
- Update to 4.2.6
* Wed Apr  6 2005 mmj@suse.de
- Update to 4.2.5
* Tue Mar 15 2005 mmj@suse.de
- Fix Makefile completion by using the _make from an older zsh
  version [#72875]
* Thu Feb 17 2005 poeml@suse.de
- update yast2 completion to also complete *.ycp files
* Thu Feb  3 2005 mmj@suse.de
- Update to 4.2.4
* Mon Jan 31 2005 ro@suse.de
- adapt to texi2html changes
* Wed Jan 26 2005 uli@suse.de
- run configure with --with-tcsetpgrp as suggested by the fail log
  (fixes s390*)
* Sat Jan 15 2005 mmj@suse.de
- Update to zsh-4.2.3 which is a bugfix release not really affecting
  us, but better keep up to date
* Wed Jan 12 2005 mmj@suse.de
- Update to zsh-4.2.2
* Mon Dec 20 2004 poeml@suse.de
- fix yast2 completion to work without /sbin in PATH [#49374]
- fix yast2 and SuSEconfig completion to not show files from
  working directory
- update hwinfo completion
* Fri Aug 13 2004 mmj@suse.de
- Update to zsh-4.2.1
* Tue Jul 27 2004 ro@suse.de
- fix build of helpfiles after groff update
* Fri Mar 19 2004 mmj@suse.de
- Update to zsh-4.2.0 final release
* Mon Mar  8 2004 mmj@suse.de
- Update to zsh-4.2.0-pre-3
* Thu Feb 26 2004 mmj@suse.de
- Update to zsh-4.2.0-pre-1
* Fri Jan 16 2004 mmj@suse.de
- Use -fprofile-arcs when linking and -fno-strict-aliasing for
  compiling.
- Fix tail syntax
* Sat Oct 18 2003 mmj@suse.de
- Fix neededforbuild
* Thu Oct 16 2003 mmj@suse.de
- Don't build as root
- Cleanup specfile
* Tue Oct 14 2003 jh@suse.de
- Fix profiling lockup.  (we can not profile dl_closed modules yet)
* Thu Jun 19 2003 mmj@suse.de
- Update to 4.1.1
- Enable profiling
* Thu May  8 2003 mmj@suse.de
- And do it even better, thanks Andreas Schwab.
* Thu May  8 2003 mmj@suse.de
- Use a better way of unaliasing 'which'. Thanks Ingo Lameter.
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Mon Apr  7 2003 mmj@suse.de
- Only delete info entries when removing last version.
* Fri Feb  7 2003 mmj@suse.de
- Use %%install_info macro
- Clean up build root
* Thu Jan  9 2003 mmj@suse.de
- Set the important option 'nopromptcr' to not screw output.
* Mon Sep 16 2002 mmj@suse.de
- Use BuildRoot
* Fri Aug 16 2002 mmj@suse.de
- Move zsh binary to /bin [#17758]
- Use proper libdir
* Thu Aug 15 2002 poeml@suse.de
- update completion for _yast{,2} and add one for _hwinfo
* Wed Aug 14 2002 mmj@suse.de
- Update to 4.0.6 which was released this fast b/c a termcap /
  terminfo fix was forgotten together with a fix for _mount.
* Mon Aug 12 2002 mmj@suse.de
- Update to 4.0.5 which includes a lot more completion, modules and
  bugfixes.
* Tue Jun  4 2002 mmj@suse.de
- Added the html documentation from the ZSH team.
* Tue Apr 16 2002 mmj@suse.de
- Fix to own %%{_defaultdocdir}/zsh
* Mon Mar 11 2002 mmj@suse.de
- Comment out a completion that a lot of people find broken
* Fri Feb 22 2002 mmj@suse.de
- Added yast2 and SuSEconfig completion from poeml@
* Wed Feb 13 2002 stepan@suse.de
- remove .orig and .rej files from patch set.
* Wed Jan 30 2002 mmj@suse.de
- Moved /etc/zshrc and /etc/zshenv to this package. This is ok b/c
  it is only specific zsh options.
* Thu Dec 13 2001 mmj@suse.de
- Fix broken symlink from help/man1 -> ../Doc
* Sat Oct 27 2001 mmj@suse.de
- Update to 4.0.4
* Thu Oct 25 2001 mmj@suse.de
- Update to 4.0.3
* Tue Jun 26 2001 mmj@suse.de
- Update to the newly released 4.0.2
* Sat Jun  2 2001 mmj@suse.de
- Updated to the new stable release, zsh-4.0.1
- Fixed build prob on beta-i386 and beta-ia64
* Tue May  8 2001 mfabian@suse.de
- bzip2 sources
* Sun Apr 15 2001 schwab@suse.de
- Fix missing declarations.
* Thu Apr 12 2001 mmj@suse.de
- Updated to 4.0.1-pre-3
* Wed Mar 14 2001 mmj@suse.de
- Updated to 4.0.1-pre-2
* Sun Feb 18 2001 mmj@suse.de
- Updated to 4.0.1-pre-1
* Fri Dec 15 2000 werner@suse.de
- Update to 3.1.9-dev-8
* Fri Oct  6 2000 kukuk@suse.de
- Change group tag
* Fri May 12 2000 schwab@suse.de
- Update config files.
- Move docs to %%{_defaultdocdir}.
* Thu Jan 27 2000 werner@suse.de
- New zsh version 3.1.6-dev-16
- Install html and info documentation
- Enable run-help help library
- Fix paths of perl and zsh scripts
- Enable command line history
- Enable command line complementation/correction
* Mon Dec  6 1999 schwab@suse.de
- Fix errors from makeinfo
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Nov 17 1998 bs@suse.de
- removed symlink /etc/zshrc -> profile (aaa_base contains a real zshrc now)
* Fri Oct 10 1997 florian@suse.de
- update to version 3.0.5
* Mon Jun 23 1997 florian@suse.de
- update to version 3.0.4
* Wed Jan 22 1997 florian@suse.de
- update to version 3.0.2
* Thu Jan  2 1997 florian@suse.de
- update to version 3.0.1
- added more documentation in binary package
* Thu Jan  2 1997 florian@suse.de
  new version 3.0.0
